# QuotasUnassign


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**organizations** | **List[str]** |  | [optional] 

## Example

```python
from thousandeyes_sdk.usage.models.quotas_unassign import QuotasUnassign

# TODO update the JSON string below
json = "{}"
# create an instance of QuotasUnassign from a JSON string
quotas_unassign_instance = QuotasUnassign.from_json(json)
# print the JSON string representation of the object
print(QuotasUnassign.to_json())

# convert the object into a dict
quotas_unassign_dict = quotas_unassign_instance.to_dict()
# create an instance of QuotasUnassign from a dict
quotas_unassign_from_dict = QuotasUnassign.from_dict(quotas_unassign_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


